@@ -97,6 +97,7 @@ public class JmsConnection implements Connection, TopicConnection, QueueConnecti
     private URI configuredURI;
     private URI connectedURI;
     private JmsPrefetchPolicy prefetchPolicy = new JmsPrefetchPolicy();
+    private JmsRedeliveryPolicy redeliveryPolicy = new JmsRedeliveryPolicy();
     private boolean localMessagePriority;
     private boolean clientIdSet;
     private boolean sendAcksAsync;
@@ -845,12 +846,28 @@ public class JmsConnection implements Connection, TopicConnection, QueueConnecti
         connectionInfo.setQueuePrefix(queuePrefix);
     }
 
+    public boolean isValidatePropertyNames() {
+        return connectionInfo.isValidatePropertyNames();
+    }
+
+    public void setValidatePropertyNames(boolean validatePropertyNames) {
+        connectionInfo.setValidatePropertyNames(validatePropertyNames);
+    }
+
     public JmsPrefetchPolicy getPrefetchPolicy() {
         return prefetchPolicy;
     }
 
     public void setPrefetchPolicy(JmsPrefetchPolicy prefetchPolicy) {
-        this.prefetchPolicy = prefetchPolicy;
+        this.prefetchPolicy = prefetchPolicy.copy();
+    }
+
+    public JmsRedeliveryPolicy getRedeliveryPolicy() {
+        return redeliveryPolicy;
+    }
+
+    public void setRedeliveryPolicy(JmsRedeliveryPolicy redeliveryPolicy) {
+        this.redeliveryPolicy = redeliveryPolicy.copy();
     }
 
     public boolean isLocalMessagePriority() {
@@ -970,10 +987,12 @@ public class JmsConnection implements Connection, TopicConnection, QueueConnecti
     public void onInboundMessage(final JmsInboundMessageDispatch envelope) {
 
         JmsMessage incoming = envelope.getMessage();
-        // Ensure incoming Messages are in readonly mode.
         if (incoming != null) {
+            // Ensure incoming Messages are in readonly mode.
             incoming.setReadOnlyBody(true);
             incoming.setReadOnlyProperties(true);
+
+            incoming.setValidatePropertyNames(isValidatePropertyNames());
         }
 
         JmsMessageDispatcher dispatcher = dispatchers.get(envelope.getConsumerId());
