@@ -62,6 +62,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private boolean localMessagePriority;
     private String queuePrefix = null;
     private String topicPrefix = null;
+    private boolean validatePropertyNames = true;
     private long sendTimeout = JmsConnectionInfo.DEFAULT_SEND_TIMEOUT;
     private long requestTimeout = JmsConnectionInfo.DEFAULT_REQUEST_TIMEOUT;
     private long closeTimeout = JmsConnectionInfo.DEFAULT_CLOSE_TIMEOUT;
@@ -73,6 +74,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private ExceptionListener exceptionListener;
 
     private JmsPrefetchPolicy prefetchPolicy = new JmsPrefetchPolicy();
+    private JmsRedeliveryPolicy redeliveryPolicy = new JmsRedeliveryPolicy();
 
     public JmsConnectionFactory() {
     }
@@ -180,7 +182,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
             JmsConnection result = new JmsConnection(connectionId, provider, getClientIdGenerator());
             return configureConnection(result, username, password);
         } catch (Exception e) {
-            throw JmsExceptionSupport.create(e);
+            throw JmsExceptionSupport.create("Failed to create connection to: " + getRemoteURI(), e);
         }
     }
 
@@ -424,6 +426,14 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         this.topicPrefix = topicPrefix;
     }
 
+    public boolean isValidatePropertyNames() {
+        return validatePropertyNames;
+    }
+
+    public void setValidatePropertyNames(boolean validatePropertyNames) {
+        this.validatePropertyNames = validatePropertyNames;
+    }
+
     /**
      * Gets the currently set close timeout.
      *
@@ -495,6 +505,25 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         this.prefetchPolicy = prefetchPolicy;
     }
 
+    /**
+     * Returns the JmsRedeliveryPolicy that is applied when a new connection is created.
+     *
+     * @return the redeliveryPolicy that is currently configured for this factory.
+     */
+    public JmsRedeliveryPolicy getRedeliveryPolicy() {
+        return redeliveryPolicy;
+    }
+
+    /**
+     * Sets the JmsRedeliveryPolicy that is applied when a new connection is created.
+     *
+     * @param redeliveryPolicy
+     *        The new redeliveryPolicy to set
+     */
+    public void setRedeliveryPolicy(JmsRedeliveryPolicy redeliveryPolicy) {
+        this.redeliveryPolicy = redeliveryPolicy;
+    }
+
     /**
      * @return the currently configured client ID prefix for auto-generated client IDs.
      */
