@@ -20,12 +20,19 @@
  */
 package org.apache.qpid.jms.integration;
 
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.NETWORK_HOST;
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.OPEN_HOSTNAME;
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.PORT;
 import static org.hamcrest.Matchers.arrayContaining;
+import static org.hamcrest.Matchers.equalTo;
+import static org.hamcrest.Matchers.nullValue;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.concurrent.CountDownLatch;
@@ -33,6 +40,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 
 import javax.jms.Connection;
+import javax.jms.ConnectionFactory;
 import javax.jms.ConnectionMetaData;
 import javax.jms.ExceptionListener;
 import javax.jms.IllegalStateException;
@@ -42,6 +50,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 
 import org.apache.qpid.jms.JmsConnection;
+import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.provider.ProviderRedirectedException;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.Wait;
@@ -49,7 +58,9 @@ import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.test.testpeer.basictypes.AmqpError;
 import org.apache.qpid.jms.test.testpeer.basictypes.ConnectionError;
 import org.apache.qpid.jms.test.testpeer.matchers.CoordinatorMatcher;
+import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.transaction.TxnCapability;
+import org.hamcrest.Matcher;
 import org.junit.Test;
 
 // TODO find a way to make the test abort immediately if the TestAmqpPeer throws an exception
@@ -113,6 +124,46 @@ public class ConnectionIntegrationTest extends QpidJmsTestCase {
         }
     }
 
+    @Test(timeout = 5000)
+    public void testAmqpHostnameSetByDefault() throws Exception {
+        doAmqpHostnameTestImpl("localhost", false, equalTo("localhost"));
+    }
+
+    @Test(timeout = 5000)
+    public void testAmqpHostnameSetByVhostOption() throws Exception {
+        String vhost = "myAmqpHost";
+        doAmqpHostnameTestImpl(vhost, true, equalTo(vhost));
+    }
+
+    @Test(timeout = 500000)
+    public void testAmqpHostnameNotSetWithEmptyVhostOption() throws Exception {
+        doAmqpHostnameTestImpl("", true, nullValue());
+    }
+
+    private void doAmqpHostnameTestImpl(String amqpHostname, boolean setHostnameOption, Matcher<?> hostnameMatcher) throws JMSException, InterruptedException, Exception, IOException {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            testPeer.expectAnonymousConnect(true, null, hostnameMatcher);
+            // Each connection creates a session for managing temporary destinations etc
+            testPeer.expectBegin(true);
+
+            String uri = "amqp://localhost:" + testPeer.getServerPort();
+            if(setHostnameOption) {
+                uri += "?amqp.vhost=" + amqpHostname;
+            }
+
+            ConnectionFactory factory = new JmsConnectionFactory(uri);
+            Connection connection = factory.createConnection();
+            // Set a clientID to provoke the actual AMQP connection process to occur.
+            connection.setClientID("clientName");
+
+            testPeer.waitForAllHandlersToComplete(1000);
+            assertNull(testPeer.getThrowable());
+
+            testPeer.expectClose();
+            connection.close();
+        }
+    }
+
     @Test(timeout = 10000)
     public void testRemotelyEndConnectionListenerInvoked() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
@@ -148,18 +199,18 @@ public class ConnectionIntegrationTest extends QpidJmsTestCase {
             final CountDownLatch done = new CountDownLatch(1);
             final AtomicReference<JMSException> asyncError = new AtomicReference<JMSException>();
 
-            final String REDIRECTED_HOSTNAME = "vhost";
-            final String REDIRECTED_NETWORK_HOST = "localhost";
-            final int REDIRECTED_PORT = 5677;
+            final String redirectVhost = "vhost";
+            final String redirectNetworkHost = "localhost";
+            final int redirectPort = 5677;
 
             // Don't set a ClientId, so that the underlying AMQP connection isn't established yet
             Connection connection = testFixture.establishConnecton(testPeer, false, null, null, null, false);
 
             // Tell the test peer to close the connection when executing its last handler
-            Map<String, Object> errorInfo = new HashMap<String, Object>();
-            errorInfo.put("hostname", REDIRECTED_HOSTNAME);
-            errorInfo.put("network-host", REDIRECTED_NETWORK_HOST);
-            errorInfo.put("port", 5677);
+            Map<Symbol, Object> errorInfo = new HashMap<Symbol, Object>();
+            errorInfo.put(OPEN_HOSTNAME, redirectVhost);
+            errorInfo.put(NETWORK_HOST, redirectNetworkHost);
+            errorInfo.put(PORT, 5677);
 
             testPeer.remotelyCloseConnection(true, ConnectionError.REDIRECT, "Connection redirected", errorInfo);
 
@@ -182,9 +233,9 @@ public class ConnectionIntegrationTest extends QpidJmsTestCase {
             assertTrue(asyncError.get().getCause() instanceof ProviderRedirectedException);
 
             ProviderRedirectedException redirect = (ProviderRedirectedException) asyncError.get().getCause();
-            assertEquals(REDIRECTED_HOSTNAME, redirect.getHostname());
-            assertEquals(REDIRECTED_NETWORK_HOST, redirect.getNetworkHost());
-            assertEquals(REDIRECTED_PORT, redirect.getPort());
+            assertEquals(redirectVhost, redirect.getHostname());
+            assertEquals(redirectNetworkHost, redirect.getNetworkHost());
+            assertEquals(redirectPort, redirect.getPort());
 
             testPeer.waitForAllHandlersToComplete(1000);
         }
