@@ -16,6 +16,9 @@
  */
 package org.apache.qpid.jms.integration;
 
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.NETWORK_HOST;
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.OPEN_HOSTNAME;
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.PORT;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
@@ -26,14 +29,17 @@ import java.util.Map;
 
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
+import javax.jms.InvalidClientIDException;
 import javax.jms.JMSException;
 
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.provider.ProviderRedirectedException;
+import org.apache.qpid.jms.provider.amqp.AmqpSupport;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.test.testpeer.basictypes.AmqpError;
 import org.apache.qpid.jms.test.testpeer.basictypes.ConnectionError;
+import org.apache.qpid.proton.amqp.Symbol;
 import org.junit.Test;
 
 /**
@@ -43,13 +49,14 @@ import org.junit.Test;
 public class FailedConnectionsIntegrationTest extends QpidJmsTestCase {
 
     @Test(timeout = 5000)
-    public void testConnectWithInvalidClientId() throws Exception {
+    public void testConnectWithInvalidClientIdThrowsJMSEWhenInvalidContainerHintNotPresent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             testPeer.rejectConnect(AmqpError.INVALID_FIELD, "Client ID already in use", null);
             try {
                 establishAnonymousConnecton(testPeer, true);
                 fail("Should have thrown JMSException");
             } catch (JMSException jmsEx) {
+                // Expected
             } catch (Exception ex) {
                 fail("Should have thrown JMSException: " + ex);
             }
@@ -58,6 +65,30 @@ public class FailedConnectionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
+    @Test(timeout = 5000)
+    public void testConnectWithInvalidClientIdThrowsICIDEWhenInvalidContainerHintPresent() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            final String remoteURI = "amqp://localhost:" + testPeer.getServerPort();
+
+            Map<Symbol, Object> errorInfo = new HashMap<Symbol, Object>();
+            errorInfo.put(AmqpSupport.INVALID_FIELD, AmqpSupport.CONTAINER_ID);
+
+            testPeer.rejectConnect(AmqpError.INVALID_FIELD, "Client ID already in use", errorInfo);
+
+            try {
+                ConnectionFactory factory = new JmsConnectionFactory(remoteURI);
+                Connection connection = factory.createConnection();
+                connection.setClientID("in-use-client-id");
+
+                fail("Should have thrown InvalidClientIDException");
+            } catch (InvalidClientIDException e) {
+                // Expected
+            }
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
+
     @Test(timeout = 5000)
     public void testConnectSecurityViolation() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
@@ -76,11 +107,11 @@ public class FailedConnectionsIntegrationTest extends QpidJmsTestCase {
 
     @Test(timeout = 5000)
     public void testConnectWithRedirect() throws Exception {
-        Map<String, Object> redirectInfo = new HashMap<String, Object>();
+        Map<Symbol, Object> redirectInfo = new HashMap<Symbol, Object>();
 
-        redirectInfo.put("hostname", "localhost");
-        redirectInfo.put("network-host", "127.0.0.1");
-        redirectInfo.put("port", 5672);
+        redirectInfo.put(OPEN_HOSTNAME, "vhost");
+        redirectInfo.put(NETWORK_HOST, "127.0.0.1");
+        redirectInfo.put(PORT, 5672);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             testPeer.rejectConnect(ConnectionError.REDIRECT, "Server is full, go away", redirectInfo);
@@ -90,7 +121,7 @@ public class FailedConnectionsIntegrationTest extends QpidJmsTestCase {
             } catch (JMSException jmsex) {
                 assertTrue(jmsex.getCause() instanceof ProviderRedirectedException);
                 ProviderRedirectedException redirectEx = (ProviderRedirectedException) jmsex.getCause();
-                assertEquals("localhost", redirectEx.getHostname());
+                assertEquals("vhost", redirectEx.getHostname());
                 assertEquals("127.0.0.1", redirectEx.getNetworkHost());
                 assertEquals(5672, redirectEx.getPort());
             } catch (Exception ex) {
