@@ -18,6 +18,7 @@
  */
 package org.apache.qpid.jms.integration;
 
+import static org.apache.qpid.jms.provider.amqp.AmqpSupport.ANONYMOUS_RELAY;
 import static org.hamcrest.Matchers.arrayContaining;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.greaterThan;
@@ -50,7 +51,6 @@ import javax.jms.Topic;
 import javax.jms.TopicSubscriber;
 
 import org.apache.qpid.jms.JmsConnection;
-import org.apache.qpid.jms.provider.amqp.AmqpConnectionProperties;
 import org.apache.qpid.jms.provider.amqp.message.AmqpDestinationHelper;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.Wait;
@@ -66,6 +66,7 @@ import org.apache.qpid.jms.test.testpeer.describedtypes.Rejected;
 import org.apache.qpid.jms.test.testpeer.describedtypes.Released;
 import org.apache.qpid.jms.test.testpeer.describedtypes.TransactionalState;
 import org.apache.qpid.jms.test.testpeer.describedtypes.sections.AmqpValueDescribedType;
+import org.apache.qpid.jms.test.testpeer.describedtypes.sections.HeaderDescribedType;
 import org.apache.qpid.jms.test.testpeer.matchers.AcceptedMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.CoordinatorMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.ModifiedMatcher;
@@ -460,7 +461,7 @@ public class SessionIntegrationTest extends QpidJmsTestCase {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
 
             //Add capability to indicate support for ANONYMOUS-RELAY
-            Symbol[] serverCapabilities = new Symbol[]{AmqpConnectionProperties.ANONYMOUS_RELAY};
+            Symbol[] serverCapabilities = new Symbol[]{ANONYMOUS_RELAY};
 
             Connection connection = testFixture.establishConnecton(testPeer, serverCapabilities);
             connection.start();
@@ -650,7 +651,7 @@ public class SessionIntegrationTest extends QpidJmsTestCase {
     public void testCreateAnonymousProducerWhenAnonymousRelayNodeIsSupported() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             //Add capability to indicate support for ANONYMOUS-RELAY
-            Symbol[] serverCapabilities = new Symbol[]{AmqpConnectionProperties.ANONYMOUS_RELAY};
+            Symbol[] serverCapabilities = new Symbol[]{ANONYMOUS_RELAY};
 
             Connection connection = testFixture.establishConnecton(testPeer, serverCapabilities);
             connection.start();
@@ -707,7 +708,7 @@ public class SessionIntegrationTest extends QpidJmsTestCase {
     private void doCreateAnonymousProducerFailsWhenAnonymousRelayNodeIsSupportedButLinkRefusedTestImpl(boolean deferAttachFrameWrite) throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             //Add capability to indicate support for ANONYMOUS-RELAY
-            Symbol[] serverCapabilities = new Symbol[]{AmqpConnectionProperties.ANONYMOUS_RELAY};
+            Symbol[] serverCapabilities = new Symbol[]{ANONYMOUS_RELAY};
 
             Connection connection = testFixture.establishConnecton(testPeer, serverCapabilities);
             connection.start();
@@ -897,6 +898,41 @@ public class SessionIntegrationTest extends QpidJmsTestCase {
         }
     }
 
+    @Test(timeout=5000)
+    public void testIncomingMessageExceedsMaxRedeliveries() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            final int COUNT = 5;
+
+            Connection connection = testFixture.establishConnecton(testPeer);
+            connection.start();
+
+            ((JmsConnection) connection).getRedeliveryPolicy().setMaxRedeliveries(1);
+
+            testPeer.expectBegin(true);
+
+            Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            Queue queue = session.createQueue("myQueue");
+
+            HeaderDescribedType header = new HeaderDescribedType();
+            header.setDeliveryCount(new UnsignedInteger(2));
+
+            testPeer.expectReceiverAttach();
+            testPeer.expectLinkFlowRespondWithTransfer(header, null, null, null, new AmqpValueDescribedType("content"), COUNT);
+
+            for (int i = 0; i < COUNT; i++) {
+                // Then expect an *settled* Modified disposition that rejects each message once
+                ModifiedMatcher modified = new ModifiedMatcher();
+                modified.withDeliveryFailed(equalTo(true));
+                modified.withUndeliverableHere(equalTo(true));
+                testPeer.expectDisposition(true, modified);
+            }
+
+            session.createConsumer(queue);
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
+
     @Test(timeout=5000)
     public void testProducedMessagesOnTransactedSessionCarryTxnId() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
