@@ -20,7 +20,6 @@ import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.JMS_B
 import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.JMS_MSG_TYPE;
 import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.getSymbol;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
@@ -273,7 +272,6 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
         assertEquals("Message reports unexpected length", length, amqpBytesMessageFacade.getBodyLength());
-        assertFalse(amqpBytesMessageFacade.isEmpty());
     }
 
     @Test
@@ -293,7 +291,6 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
         assertEquals("Message reports unexpected length", 0, amqpBytesMessageFacade.getBodyLength());
-        assertTrue(amqpBytesMessageFacade.isEmpty());
     }
 
     @Test
@@ -399,24 +396,6 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         }
     }
 
-    @Test
-    public void testIsEmpty() throws Exception {
-        Message message = Message.Factory.create();
-        message.setBody(new Data(new Binary(new byte[1])));
-        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
-
-        // Very small payload.
-        assertFalse(amqpBytesMessageFacade.isEmpty());
-
-        // Ensure no NPE
-        message.setBody(null);
-        assertTrue(amqpBytesMessageFacade.isEmpty());
-
-        byte[] bytes = "myBytes".getBytes();
-        message.setBody(new AmqpValue(new Binary(bytes)));
-        assertFalse(amqpBytesMessageFacade.isEmpty());
-    }
-
     /**
      * Test that setting bytes on a received message results in the expected content in the body section
      * of the underlying message and returned by a new InputStream requested from the message.
