@@ -37,7 +37,7 @@ import java.util.concurrent.TimeUnit;
 
 import javax.net.ssl.SSLContext;
 
-import org.apache.qpid.jms.provider.amqp.AmqpConnection;
+import org.apache.qpid.jms.provider.amqp.AmqpSupport;
 import org.apache.qpid.jms.provider.amqp.AmqpTemporaryDestination;
 import org.apache.qpid.jms.provider.amqp.message.AmqpDestinationHelper;
 import org.apache.qpid.jms.test.testpeer.basictypes.ReceiverSettleMode;
@@ -364,12 +364,37 @@ public class TestAmqpPeer implements AutoCloseable
         return openFrame;
     }
 
-    public void expectAnonymousConnect(boolean authorize)
+    public void expectFailingSaslConnect(Symbol[] serverMechs, Symbol clientSelectedMech)
     {
-        expectAnonymousConnect(authorize, null);
+        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(serverMechs);
+        addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
+                                            new FrameSender(
+                                                    this, FrameType.SASL, 0,
+                                                    saslMechanismsFrame, null)));
+
+        SaslInitMatcher saslInitMatcher = new SaslInitMatcher().withMechanism(equalTo(clientSelectedMech));
+        saslInitMatcher.onSuccess(new AmqpPeerRunnable()
+        {
+            @Override
+            public void run()
+            {
+                TestAmqpPeer.this.sendFrame(
+                        FrameType.SASL, 0,
+                        new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)1)),
+                        null,
+                        false);
+                _driverRunnable.expectHeader();
+            }
+        });
+        addHandler(saslInitMatcher);
     }
 
-    public void expectAnonymousConnect(boolean authorize, Matcher<?> idleTimeoutMatcher)
+    public void expectAnonymousConnect(boolean authorize)
+    {
+        expectAnonymousConnect(authorize, null, null);
+    }
+
+    public void expectAnonymousConnect(boolean authorize, Matcher<?> idleTimeoutMatcher, Matcher<?> hostnameMatcher)
     {
         SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("ANONYMOUS"));
         addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
@@ -377,9 +402,9 @@ public class TestAmqpPeer implements AutoCloseable
                                                     this, FrameType.SASL, 0,
                                                     saslMechanismsFrame, null)));
 
-        addHandler(new SaslInitMatcher()
+        SaslInitMatcher saslInitMatcher = new SaslInitMatcher()
             .withMechanism(equalTo(Symbol.valueOf("ANONYMOUS")))
-            .withInitialResponse(nullValue())
+            .withInitialResponse(equalTo(new Binary(new byte[0])))
             .onSuccess(new AmqpPeerRunnable()
             {
                 @Override
@@ -392,7 +417,14 @@ public class TestAmqpPeer implements AutoCloseable
                             false);
                     _driverRunnable.expectHeader();
                 }
-            }));
+            });
+
+        if(hostnameMatcher != null)
+        {
+            saslInitMatcher.withHostname(hostnameMatcher);
+        }
+
+        addHandler(saslInitMatcher);
 
         addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
 
@@ -410,14 +442,20 @@ public class TestAmqpPeer implements AutoCloseable
             openMatcher.withIdleTimeOut(idleTimeoutMatcher);
         }
 
+        if(hostnameMatcher != null)
+        {
+            openMatcher.withHostname(hostnameMatcher);
+        }
+
         addHandler(openMatcher);
     }
 
-    /**
-     * NOTE: this is only testing use of the mechanism, there is no SSL here yet.
-     */
     public void expectExternalConnect()
     {
+        if(!_driverRunnable.isNeedClientCert()) {
+            throw new IllegalStateException("Need client cert must be enabled");
+        }
+
         SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("EXTERNAL"));
         addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
                                             new FrameSender(
@@ -455,7 +493,7 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void expectPlainConnect(String username, String password, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
     {
-        expectPlainConnect(username, password, new Symbol[] { AmqpConnection.SOLE_CONNECTION_CAPABILITY }, serverCapabilities, serverProperties);
+        expectPlainConnect(username, password, new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, serverCapabilities, serverProperties);
     }
 
     public void expectPlainConnect(String username, String password, Symbol[] desiredCapabilities, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
@@ -519,8 +557,7 @@ public class TestAmqpPeer implements AutoCloseable
     }
 
     // TODO - Reject any incoming connection using the supplied information
-    public void rejectConnect(Symbol errorType, String errorMessage, Map<String, Object> errorInfo) {
-
+    public void rejectConnect(Symbol errorType, String errorMessage, Map<Symbol, Object> errorInfo) {
         SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("ANONYMOUS"));
         addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
                                             new FrameSender(
@@ -529,7 +566,7 @@ public class TestAmqpPeer implements AutoCloseable
 
         addHandler(new SaslInitMatcher()
             .withMechanism(equalTo(Symbol.valueOf("ANONYMOUS")))
-            .withInitialResponse(nullValue())
+            .withInitialResponse(equalTo(new Binary(new byte[0])))
             .onSuccess(new AmqpPeerRunnable()
             {
                 @Override
@@ -575,16 +612,25 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void expectClose()
     {
-        expectClose(Matchers.nullValue());
+        expectClose(Matchers.nullValue(), true);
     }
 
-    public void expectClose(Matcher<?> errorMatcher)
+    public void expectClose(Matcher<?> errorMatcher, boolean sendReply)
     {
-        addHandler(new CloseMatcher()
-            .withError(errorMatcher)
-            .onSuccess(new FrameSender(this, FrameType.AMQP, 0,
+        CloseMatcher closeMatcher = new CloseMatcher().withError(errorMatcher);
+        if(sendReply) {
+            closeMatcher.onSuccess(new FrameSender(this, FrameType.AMQP, 0,
                     new CloseFrame(),
-                    null)));
+                    null));
+        }
+
+        addHandler(closeMatcher);
+    }
+
+    public void expectHeaderAndOpen()
+    {
+        addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
+        addHandler(new OpenMatcher());
     }
 
     public void expectBegin(boolean expectSessionFlow)
@@ -1400,7 +1446,7 @@ public class TestAmqpPeer implements AutoCloseable
         remotelyCloseConnection(expectCloseResponse, errorType, errorMessage, null);
     }
 
-    public void remotelyCloseConnection(boolean expectCloseResponse, Symbol errorType, String errorMessage, Map<String, Object> info) {
+    public void remotelyCloseConnection(boolean expectCloseResponse, Symbol errorType, String errorMessage, Map<Symbol, Object> info) {
         synchronized (_handlersLock) {
             // Prepare a composite to insert this action at the end of the handler sequence
             CompositeAmqpPeerRunnable comp = insertCompsiteActionForLastHandler();
